function X = MDCT(x)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Efficient computation of MDCT coefficients           %
% Windowing is not included and length(x) must be even %
% Olivier Derrien - LMA/CNRS - 02.2015                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Get MDCT size
N = length(x);
if rem(N,2) ~= 0
    disp('Error: input-signal length must be even')
    return
else
    N = N/2;
end

% Force x to be a line vector
if size(x,2) == 1
    x = x';
end

% Discrete time and frequency vectors 
t = [0:2*N-1];
f = [0:N-1];

% MDCT computation using FFT
X = x .* exp(-j*pi*t/2/N);
X = fft(X);
X = X(1:N);
X = sqrt(2/N)*real(X .* exp(-j*pi*(f+0.5)*(N+1)/2/N));
